#include "stdio.h"
#include "stdlib.h"

#define NO_ERRORS 0
#define NEGATIVE_MEMBERS 1
#define ZERO_MEMBERS 2
#define GREATER_THAN_1000_MEMMBERS 3
#define NO_INPUT 4
#define EMPTY_INPUT 5

int CheckSum(int *, int, int *);
int* CreateRandomArray(int, int, int);
void CheckError(int);

int CheckSum(int *pInput, int n, int *pError)
{
	if (!pInput)
	{
		*pError = NO_INPUT;
		return 0;
	}
	if (!n)
	{
		*pError = EMPTY_INPUT;
		return 0;
	}
	int sum = 0, i = 0;
	for (; i < n; i++)
	{
		if (!*(pInput + i))
		{
			*pError = ZERO_MEMBERS;
			return 0;
		}
		if (*(pInput + i) < 0)
		{
			*pError = NEGATIVE_MEMBERS;
			return 0;
		}
		if (*(pInput + i) > 1000)
		{
			*pError = GREATER_THAN_1000_MEMMBERS;
			return 0;
		}
		sum += *(pInput + i);
	}
	*pError = NO_ERRORS;
	return sum;
}

int *CreateRandomArray(int n, int lower, int upper)
{
	if (n <= 0 || lower >= upper)
	{
		return 0;
	}
	int *pResult = (int *)malloc(n * sizeof(int));
	for (int i = 0; i < n; i++)
	{
		*(pResult + i) = lower + rand() % (upper - lower + 1);
	}
	return pResult;
}

void CheckError(int error)
{
	switch (error)
	{
	case NO_ERRORS:
		printf("No errors\n");
		break;
	case NEGATIVE_MEMBERS:
		printf("Failure, negative numbers in array!\n");
		break; 
	case ZERO_MEMBERS:
		printf("Failure, zero numbers in array!\n");
		break;
	case GREATER_THAN_1000_MEMMBERS:
		printf("Failure, greater than 1000 numbers in array!\n");
		break;
	case NO_INPUT:
		printf("Failure, input array does not exist!\n");
		break;
	case EMPTY_INPUT:
		printf("Failure, no members in input array!\n");
		break;
	}
}

int main()
{
	int *pIn = CreateRandomArray(10, 1, 999);
	int error;
	int Result = CheckSum(pIn, 10, &error);
	CheckError(error);
	printf("%d\n", Result);
	free(pIn);

	pIn = CreateRandomArray(10, -999, 999);
	Result = CheckSum(pIn, 10, &error);
	CheckError(error);
	printf("%d\n", Result);
	free(pIn);

	pIn = CreateRandomArray(10, 1, 1100);
	Result = CheckSum(pIn, 10, &error);
	CheckError(error);
	printf("%d\n", Result);
	free(pIn);

	int buf[2] = { 10, 0 };
	Result = CheckSum(buf, 10, &error);
	CheckError(error);
	printf("%d\n", Result);

	Result = CheckSum(0, 10, &error);
	CheckError(error);
	printf("%d\n", Result);

	Result = CheckSum(buf, 0, &error);
	CheckError(error);
	printf("%d\n", Result);

	return 0;
}

